==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/FormatSpecifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSpecifierDescription } from "./FormatSpecifierDescription";
/**
 * @hidden
 */
export let FormatSpecifierDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatSpecifierDescriptionMetadata extends Base {
        static b(a) {
            if (FormatSpecifierDescriptionMetadata.a == null) {
                FormatSpecifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatSpecifierDescriptionMetadata.c(FormatSpecifierDescriptionMetadata.a);
            }
            if (a.k(FormatSpecifierDescriptionMetadata.a)) {
                return;
            }
            a.ab(FormatSpecifierDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            FormatSpecifierDescriptionMetadata.b(a);
            a.ad("FormatSpecifier", () => new FormatSpecifierDescription());
            a.ac("FormatSpecifier", FormatSpecifierDescriptionMetadata.a);
        }
    }
    FormatSpecifierDescriptionMetadata.$t = /*@__PURE__*/ markType(FormatSpecifierDescriptionMetadata, 'FormatSpecifierDescriptionMetadata');
    FormatSpecifierDescriptionMetadata.a = null;
    return FormatSpecifierDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/FormatSpecifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSpecifierDescription } from "./FormatSpecifierDescription";
/**
 * @hidden
 */
export let FormatSpecifierDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatSpecifierDescriptionMetadata extends Base {
        static b(a) {
            if (FormatSpecifierDescriptionMetadata.a == null) {
                FormatSpecifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatSpecifierDescriptionMetadata.c(FormatSpecifierDescriptionMetadata.a);
            }
            if (a.k(FormatSpecifierDescriptionMetadata.a)) {
                return;
            }
            a.ac(FormatSpecifierDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
        }
        static d(a) {
            FormatSpecifierDescriptionMetadata.b(a);
            a.ae("FormatSpecifier", () => new FormatSpecifierDescription());
            a.ad("FormatSpecifier", FormatSpecifierDescriptionMetadata.a);
        }
    }
    FormatSpecifierDescriptionMetadata.$t = /*@__PURE__*/ markType(FormatSpecifierDescriptionMetadata, 'FormatSpecifierDescriptionMetadata');
    FormatSpecifierDescriptionMetadata.a = null;
    return FormatSpecifierDescriptionMetadata;
})();
